@@ -2505,6 +2505,9 @@ Serializes subtree subtended by invocant to newick string.
 
 =head1 SEE ALSO
 
+There is a mailing list at L<https://groups.google.com/forum/#!forum/bio-phylo> 
+for any user or developer questions and discussions.
+
 =over
 
 =item L<Bio::Phylo::Taxa::TaxonLinker>
